@@ -20,20 +20,30 @@ class MediaCorpusAdmin(admin.ModelAdmin):
     ordering = ['code']
     filter_horizontal = ['children']
 
+class MediaCollectionRelatedInline(admin.StackedInline):
+    model = MediaCollectionRelated
+
 class MediaCollectionAdmin(admin.ModelAdmin):
     search_fields = ['title', 'code']
     ordering = ['code']
+    inlines = [MediaCollectionRelatedInline]
 
-class MediaCollectionRelatedAdmin(admin.ModelAdmin):
-    search_fields = ['title', 'description']
+class MediaItemRelatedInline(admin.StackedInline):
+    model = MediaItemRelated
+
+class MediaItemMarkerInline(admin.StackedInline):
+    model = MediaItemMarker
+
+class MediaItemTranscodedInline(admin.StackedInline):
+    model = MediaItemTranscoded
 
 class MediaItemAdmin(admin.ModelAdmin):
     search_fields = ['title', 'code']
     ordering = ['code']
     exclude = ('copied_from_item', )
-
-class MediaItemRelatedAdmin(admin.ModelAdmin):
-    search_fields = ['title', 'description']
+    inlines = [MediaItemRelatedInline, 
+                MediaItemTranscodedInline,
+                MediaItemMarkerInline]
 
 class MediaPartAdmin(admin.ModelAdmin):
     search_fields = ['title', 'item__code']
@@ -90,10 +100,6 @@ admin.site.register(MediaCollection, MediaCollectionAdmin)
 admin.site.register(MediaItem, MediaItemAdmin)
 admin.site.register(MediaPart, MediaPartAdmin)
 
-admin.site.register(MediaItemRelated, MediaItemRelatedAdmin)
-admin.site.register(MediaCollectionRelated, MediaCollectionRelatedAdmin)
-admin.site.register(MediaItemTranscoded)
-
 admin.site.register(Instrument, InstrumentAdmin)
 admin.site.register(InstrumentAlias, InstrumentAliasAdmin)
 admin.site.register(InstrumentRelation, InstrumentRelationAdmin)
