@@ -151,7 +151,7 @@ class DurationField(models.Field):
     }
 
     def __init__(self, *args, **kwargs):
-        super(DurationField, self).__init__(*args, **normalize_field(kwargs, '00:00'))
+        super(DurationField, self).__init__(*args, **normalize_field(kwargs, '0'))
 
     def db_type(self):
         return 'int'
@@ -279,7 +279,6 @@ class CharField(models.CharField):
     def __init__(self, *args, **kwargs):
         if not kwargs.has_key('max_length'):
             kwargs['max_length'] = 250
-
         super(CharField, self).__init__(*args, **normalize_field(kwargs, ''))
 
 class IntegerField(models.IntegerField):
@@ -346,12 +345,12 @@ class ModelCore(EnhancedModel):
                 required.append(field)
         return required
 
-    def save(self, force_insert=False, force_update=False):
+    def save(self, force_insert=False, force_update=False, *args, **kwargs):
         required = self.required_fields()
         for field in required:
             if not getattr(self, field.name):
                 raise RequiredFieldError(self, field)
-        super(ModelCore, self).save(force_insert, force_update)
+        super(ModelCore, self).save(force_insert, force_update, *args, **kwargs)
 
     @classmethod
     def get_dom_name(cls):
