@@ -52,6 +52,7 @@ from telemeta.models.language import *
 from telemeta.models.format import *
 from telemeta.util.kdenlive.session import *
 from django.db import models
+from django.db.models import URLField
 from django.conf import settings
 
 
@@ -121,7 +122,8 @@ class MediaBaseResource(MediaResource):
     "Describe a media base resource"
 
     title                 = CharField(_('title'), required=True)
-    description           = CharField(_('description'))
+    description           = CharField(_('description_old'))
+    descriptions          = TextField(_('description'))
     code                  = CharField(_('code'), unique=True, required=True)
     public_access         = CharField(_('public access'), choices=PUBLIC_ACCESS_CHOICES,
                                       max_length=16, default="metadata")
@@ -408,6 +410,7 @@ class MediaItem(MediaResource):
     # Media
     file                  = FileField(_('file'), upload_to='items/%Y/%m/%d',
                                       db_column="filename", max_length=1024)
+    url                   = URLField(_('URL'), max_length=512, blank=True)
 
     # Technical data
     approx_duration       = DurationField(_('approximative duration'))
@@ -481,6 +484,14 @@ class MediaItem(MediaResource):
             title += ' ' + self.track
         return title
 
+    def get_source(self):
+        source = None
+        if self.file and os.path.exists(self.file.path):
+            source = self.file.path
+        elif self.url:
+            source = self.url
+        return source
+
     @property
     def instruments(self):
         "Return the instruments of the item"
@@ -775,6 +786,13 @@ class MediaCorpus(MediaBaseResource):
     @property
     def public_id(self):
         return self.code
+    
+    @property
+    def has_mediafile(self):
+        for child in self.children.all():
+            if child.has_mediafile:
+                return True
+        return False
 
     class Meta(MetaCore):
         db_table = 'media_corpus'
@@ -797,6 +815,13 @@ class MediaFonds(MediaBaseResource):
     def public_id(self):
         return self.code
 
+    @property
+    def has_mediafile(self):
+        for child in self.children.all():
+            if child.has_mediafile:
+                return True
+        return False
+
     class Meta(MetaCore):
         db_table = 'media_fonds'
         verbose_name = _('fonds')
