@@ -34,9 +34,10 @@
 # Authors: Olivier Guilyardi <olivier@samalyse.com>
 #          Guillaume Pellerin <yomguy@parisson.com>
 
-import mimetypes
+
 from telemeta.views.core import *
 
+
 class ItemView(object):
     """Provide Item web UI methods"""
 
@@ -44,11 +45,15 @@ class ItemView(object):
     decoders = timeside.core.processors(timeside.api.IDecoder)
     encoders = timeside.core.processors(timeside.api.IEncoder)
     analyzers = timeside.core.processors(timeside.api.IAnalyzer)
+    value_analyzers = timeside.core.processors(timeside.api.IValueAnalyzer)
     cache_data = TelemetaCache(settings.TELEMETA_DATA_CACHE_DIR)
     cache_export = TelemetaCache(settings.TELEMETA_EXPORT_CACHE_DIR)
 
     export_enabled = getattr(settings, 'TELEMETA_DOWNLOAD_ENABLED', True)
     export_formats = getattr(settings, 'TELEMETA_DOWNLOAD_FORMATS', ('mp3', 'wav'))
+    default_grapher_id = getattr(settings, 'TIMESIDE_DEFAULT_GRAPHER_ID', ('waveform_simple'))
+    default_grapher_sizes = getattr(settings, 'TELEMETA_DEFAULT_GRAPHER_SIZES', ['360x130', ])
+    auto_zoom = getattr(settings, 'TIMESIDE_AUTO_ZOOM', False)
 
     def get_export_formats(self):
         formats = []
@@ -92,6 +97,21 @@ class ItemView(object):
 
         return previous, next
 
+    def get_graphers(self):
+        graphers = []
+        for grapher in self.graphers:
+            if grapher.id() == self.default_grapher_id:
+                graphers.insert(0, {'name':grapher.name(), 'id': grapher.id()})
+            else:
+                graphers.append({'name':grapher.name(), 'id': grapher.id()})
+        return graphers
+
+    def get_grapher(self, id):
+        for grapher in self.graphers:
+            if grapher.id() == id:
+                break
+        return grapher
+
     def item_detail(self, request, public_id=None, marker_id=None, width=None, height=None,
                         template='telemeta/mediaitem_detail.html'):
         """Show the details of a given item"""
@@ -113,15 +133,6 @@ class ItemView(object):
             messages.error(request, title)
             return render(request, 'telemeta/messages.html', {'description' : description})
 
-        graphers = []
-        for grapher in self.graphers:
-            graphers.append({'name':grapher.name(), 'id': grapher.id()})
-            
-        if request.REQUEST.has_key('grapher_id'):
-            grapher_id = request.REQUEST['grapher_id']
-        else:
-            grapher_id = getattr(settings, 'TELEMETA_DEFAULT_GRAPHER_ID', 'waveform')
-
         previous, next = self.item_previous_next(item)
 
         mime_type = self.item_analyze(item)
@@ -145,7 +156,7 @@ class ItemView(object):
 
         return render(request, template,
                     {'item': item, 'export_formats': self.get_export_formats(),
-                    'visualizers': graphers, 'visualizer_id': grapher_id,
+                    'visualizers': self.get_graphers(), 'auto_zoom': self.auto_zoom,
                     'audio_export_enabled': self.export_enabled,
                     'previous' : previous, 'next' : next, 'marker': marker_id, 'playlists' : playlists,
                     'access': access, 'width': width, 'height': height,
@@ -159,19 +170,10 @@ class ItemView(object):
         item = MediaItem.objects.get(public_id=public_id)
         access = get_item_access(item, request.user)
 
-        graphers = []
-        for grapher in self.graphers:
-            graphers.append({'name':grapher.name(), 'id': grapher.id()})
-        if request.REQUEST.has_key('grapher_id'):
-            grapher_id = request.REQUEST['grapher_id']
-        else:
-            try:
-                grapher_id = settings.TELEMETA_DEFAULT_GRAPHER_ID
-            except:
-                grapher_id = 'waveform'
-
         previous, next = self.item_previous_next(item)
+
         mime_type = self.item_analyze(item)
+
         #FIXME: use mimetypes.guess_type
         if 'quicktime' in mime_type:
             mime_type = 'video/mp4'
@@ -207,7 +209,7 @@ class ItemView(object):
         return render(request, template,
                     {'item': item,
                      'export_formats': self.get_export_formats(),
-                    'visualizers': graphers, 'visualizer_id': grapher_id,
+                    'visualizers': self.get_graphers(),
                     'audio_export_enabled': self.export_enabled,
                     'forms': forms, 'previous' : previous,
                     'next' : next, 'mime_type': mime_type, 'access': access,
@@ -216,8 +218,16 @@ class ItemView(object):
     def related_media_item_stream(self, request, item_public_id, media_id):
         item = MediaItem.objects.get(public_id=item_public_id)
         media = MediaItemRelated.objects.get(item=item, id=media_id)
+        filename = media.file.path.split(os.sep)[-1]
         response = HttpResponse(stream_from_file(media.file.path), mimetype=media.mime_type)
-#        response['Content-Disposition'] = 'attachment; '+'filename='+media.title+'.'+ext
+        return response
+
+    def related_media_item_download(self, request, item_public_id, media_id):
+        item = MediaItem.objects.get(public_id=item_public_id)
+        media = MediaItemRelated.objects.get(item=item, id=media_id)
+        filename = media.file.path.split(os.sep)[-1]
+        response = HttpResponse(stream_from_file(media.file.path), mimetype=media.mime_type)
+        response['Content-Disposition'] = 'attachment; ' + 'filename=' + filename
         return response
 
     @method_decorator(permission_required('telemeta.change_mediaitem'))
@@ -344,7 +354,7 @@ class ItemView(object):
         return redirect('telemeta-collection-detail', collection.code)
 
     def item_analyze(self, item):
-        analyses = MediaItemAnalysis.objects.filter(item=item)
+        analyses = item.analysis.all()
         mime_type = ''
 
         if analyses:
@@ -363,29 +373,25 @@ class ItemView(object):
             analyzers_sub = []
             graphers_sub = []
 
-            if item.file and os.path.exists(item.file.path):
-                decoder  = timeside.decoder.FileDecoder(item.file.path)
+            source = item.get_source()
+            if source:
+                decoder  = timeside.decoder.file.FileDecoder(source)
                 pipe = decoder
 
-                for analyzer in self.analyzers:
+                for analyzer in self.value_analyzers:
                     subpipe = analyzer()
                     analyzers_sub.append(subpipe)
                     pipe = pipe | subpipe
 
-                try:
-                    sizes = settings.TELEMETA_DEFAULT_GRAPHER_SIZES
-                except:
-                    sizes = ['360x130', ]
-
-                for grapher in self.graphers:
-                    for size in sizes:
-                        width = size.split('x')[0]
-                        height = size.split('x')[1]
-                        image_file = '.'.join([item.public_id, grapher.id(), size.replace('x', '_'), 'png'])
-                        path = self.cache_data.dir + os.sep + image_file
-                        graph = grapher(width = int(width), height = int(height))
-                        graphers_sub.append({'graph' : graph, 'path': path})
-                        pipe = pipe | graph
+                default_grapher = self.get_grapher(self.default_grapher_id)
+                for size in self.default_grapher_sizes:
+                    width = size.split('x')[0]
+                    height = size.split('x')[1]
+                    image_file = '.'.join([item.public_id, self.default_grapher_id, size.replace('x', '_'), 'png'])
+                    path = self.cache_data.dir + os.sep + image_file
+                    graph = default_grapher(width = int(width), height = int(height))
+                    graphers_sub.append({'graph' : graph, 'path': path})
+                    pipe = pipe | graph
 
                 pipe.run()
 
@@ -395,7 +401,7 @@ class ItemView(object):
                     grapher['graph'].render(grapher['path'])
                     f.close()
 
-                mime_type = mimetypes.guess_type(item.file.path)[0]
+                mime_type = mimetypes.guess_type(source)[0]
                 analysis = MediaItemAnalysis(item=item, name='MIME type',
                                              analyzer_id='mime_type', unit='', value=mime_type)
                 analysis.save()
@@ -417,11 +423,14 @@ class ItemView(object):
                 analysis.save()
 
                 for analyzer in analyzers_sub:
-                    value = analyzer.result()
-                    analysis = MediaItemAnalysis(item=item, name=analyzer.name(),
-                                                 analyzer_id=analyzer.id(),
-                                                 unit=analyzer.unit(), value=str(value))
-                    analysis.save()
+                    for key in analyzer.results.keys():
+                        result = analyzer.results[key]
+                        value = result.data_object.value
+                        if value.shape[0] == 1:
+                            value = value[0]
+                        analysis = MediaItemAnalysis(item=item, name=result.name,
+                                analyzer_id=result.id, unit=result.unit, value = unicode(value))
+                        analysis.save()
 
 #                FIXME: parse tags on first load
 #                tags = decoder.tags
@@ -430,7 +439,7 @@ class ItemView(object):
 
     def item_analyze_xml(self, request, public_id):
         item = MediaItem.objects.get(public_id=public_id)
-        analyses = MediaItemAnalysis.objects.filter(item=item)
+        analyses = item.analysis.all()
         analyzers = []
         for analysis in analyses:
             analyzers.append(analysis.to_dict())
@@ -439,14 +448,10 @@ class ItemView(object):
         response['Content-Disposition'] = 'attachment; filename='+public_id+'.xml'
         return response
 
-    def item_visualize(self, request, public_id, visualizer_id, width, height):
+    def item_visualize(self, request, public_id, grapher_id, width, height):
         item = MediaItem.objects.get(public_id=public_id)
         mime_type = 'image/png'
-        grapher_id = visualizer_id
-
-        for grapher in self.graphers:
-            if grapher.id() == grapher_id:
-                break
+        grapher = self.get_grapher(grapher_id)
 
         if grapher.id() != grapher_id:
             raise Http404
@@ -454,11 +459,18 @@ class ItemView(object):
         size = width + '_' + height
         image_file = '.'.join([public_id, grapher_id, size, 'png'])
 
+        # FIX waveform grapher name change
+        old_image_file = '.'.join([public_id, 'waveform', size, 'png'])
+        if 'waveform_centroid' in grapher_id and self.cache_data.exists(old_image_file):
+            image_file = old_image_file
+
         if not self.cache_data.exists(image_file):
-            if item.file:
+            source = item.get_source()
+            if source:
                 path = self.cache_data.dir + os.sep + image_file
-                decoder  = self.decoders[0](item.file.path)
+                decoder  = timeside.decoder.file.FileDecoder(source)
                 graph = grapher(width = int(width), height = int(height))
+                print graph.id()
                 (decoder | graph).run()
                 graph.watermark('timeside', opacity=.6, margin=(5,5))
                 f = open(path, 'w')
@@ -515,7 +527,7 @@ class ItemView(object):
 
         mime_type = encoder.mime_type()
         file = public_id + '.' + encoder.file_extension()
-        audio = item.file.path
+        source = item.get_source()
 
         flag = MediaItemTranscodingFlag.objects.filter(item=item, mime_type=mime_type)
         if not flag:
@@ -533,24 +545,25 @@ class ItemView(object):
         if mime_type in format:
             # source > stream
             if not extension in mapping.unavailable_extensions:
-                proc = encoder(audio, overwrite=True)
+                proc = encoder(source, overwrite=True)
                 proc.set_metadata(metadata)
                 try:
+                    #FIXME: should test if metadata writer is available
                     proc.write_metadata()
                 except:
                     pass
-            response = HttpResponse(stream_from_file(audio), mimetype = mime_type)
+            response = HttpResponse(stream_from_file(source), mimetype = mime_type)
         else:
             media = self.cache_export.dir + os.sep + file
             if not self.cache_export.exists(file) or not flag.value:
                 # source > encoder > stream
-                decoder = self.decoders[0](audio)
-                decoder.setup()
+                decoder = timeside.decoder.file.FileDecoder(source)
                 proc = encoder(media, streaming=True, overwrite=True)
-                proc.setup(channels=decoder.channels(), samplerate=decoder.samplerate())
                 if extension in mapping.unavailable_extensions:
                     metadata=None
-                response = HttpResponse(stream_from_processor(decoder, proc, flag, metadata=metadata), mimetype = mime_type)
+                proc.set_metadata(metadata)
+
+                response = HttpResponse(stream_from_processor(decoder, proc, flag), mimetype = mime_type)
             else:
                 # cache > stream
                 response = HttpResponse(self.cache_export.read_stream_bin(file), mimetype = mime_type)
